/*
 * Created: 02/01/10-23:31:15
 * Author: Stephen Lacey
 */
#include <QtGui/QApplication>
#include "mainwindow.h"

int main(int argc, char *argv[])
{
    QApplication a(argc, argv);
    QCoreApplication::setOrganizationName("Shep");
    QCoreApplication::setOrganizationDomain("maemo.org");
    QCoreApplication::setApplicationName("sitrep");

    MainWindow w;
    w.show();
    return a.exec();
}
